package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````_!\```````!``````````*B3````
M````!0```$``.``)`$``&0`8``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````A`````````"$``````````0`````````!````
M!0```````````````````````````````````+R,````````O(P`````````
M$`````````$````&````R(T```````#(G0```````,B=````````P`0`````
M``#H%``````````0`````````@````8```#@C0```````."=````````X)T`
M```````@`@```````"`"````````"``````````$````!````%P"````````
M7`(```````!<`@```````$0`````````1``````````$`````````%#E=&0$
M````>(P```````!XC````````'B,````````%``````````4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,B-````````R)T```````#(G0``
M`````#@"````````.`(````````!`````````"]L:6(O;&0M;&EN=7@M<FES
M8W8V-"UL<#8T9"YS;RXQ``````0````4`````P```$=.50"($F<E<'+E)/P8
MJSIG3^Z:C7A&A`0````0`````0```$=.50``````!`````\`````````$0``
M`$@````$````"````""0$`$%0`3$*`(!!("&!(2""0``"2`$"(B@$$6Z``*(
M`````$@```!+````3@```$\```!6````5P```%D```!;````70```%\```!A
M````8P```&0```!F``````````````!NQ=\?SMY'+6M_FGPNQ9NV(/_D#M5D
MU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QF&7X*
MAT)%U>R)!W#3#!3BGG-0G]C:S>.>,V+;[3[/TFP5C"7,##J7"_]A\F%_J9R;
MX*<""FL:GE"CX/M)``````````````````````````````````````,`#`!0
M'@``````````````````F`(``!(``````````````````````````0```"``
M````````````````````````^`$``!(`````````````````````````70$`
M`!(`````````````````````````-@$``!(`````````````````````````
MK@(``!(`````````````````````````(0(``!(`````````````````````
M````T`(``!$`````````````````````````O`(``!(`````````````````
M````````&P(``!(`````````````````````````90```!(`````````````
M````````````1`(``!(`````````````````````````H0$``!(`````````
M````````````````S0```!(`````````````````````````P@```!$`````
M````````````````````;P$``!(`````````````````````````?P(``!(`
M````````````````````````D`$``!(`````````````````````````*`$`
M`!(`````````````````````````I````!$`````````````````````````
M>`(``!(`````````````````````````]@```!(`````````````````````
M````Q`$``!(`````````````````````````;P(``!(`````````````````
M````````9`$``!(`````````````````````````I@(``!(`````````````
M````````````NP$``!(`````````````````````````+P(``!(`````````
M````````````````40$``!(`````````````````````````!@(``!(`````
M````````````````````J0$``!(`````````````````````````Z@$``!(`
M````````````````````````Z@(``!$`````````````````````````!`$`
M`!(`````````````````````````:`(``!(`````````````````````````
M3P(``!(`````````````````````````10```!(`````````````````````
M````SP(``"$`````````````````````````U0$``!(`````````````````
M````````@P$``!(`````````````````````````=````!(`````````````
M````````````W`$``!(`````````````````````````@````!(`````````
M````````````````'0$``!(`````````````````````````XP```!(`````
M````````````````````-P```!(`````````````````````````UP```!(`
M````````````````````````\0$``!(`````````````````````````1@$`
M`!(`````````````````````````L0```!(`````````````````````````
MLP$``!(`````````````````````````-@(``!(`````````````````````
M````%`(``!(`````````````````````````5P(``!(`````````````````
M````````K@$``!(`````````````````````````5````!(`````````````
M````````````80(``!$`````````````````````````V`(``!(`````````
M````````````````E0```!(`````````````````````````%`$``!(`````
M````````````````````B0(``"(`````````````````````````S@(``!$`
M````````````````````````'0```"``````````````````````````_P$`
M`!(`````````````````````````=0,``!(`````````````````````````
MX@$``!(`````````````````````````B0$``!(`````````````````````
M````M0(``!(`````````````````````````#0(``!(`````````````````
M````````T@```!(`````````````````````````B@,``!(`#`!L-@``````
M`.@`````````U0,``!(`#``0+@```````(X&````````R0(``!(`#`!0'@``
M`````*H!````````4@,``!(`#`!2)P````````(`````````>P0``!(`#`!4
M)P```````,0!````````L00``!(`#`">-````````,X!````````9P0``!``
M%@"(H@``````````````````O`,``!(`#``8*0```````!X`````````X@,`
M`!(`#``<2@```````-@`````````^@,``!$`#0#P3`````````0`````````
M.00``!``%@"PL@``````````````````<P0``!(`#`!F)@```````#(`````
M````B`0``!(`#`!4+0```````+P`````````F@0``!(`#`#<+````````&``
M````````[0,``!``%```H```````````````````R0,``!(`#``V*0``````
M`!8`````````/@0``!``\?^(J@``````````````````E@,``!``%0"(H@``
M````````````````+P0``!$`%`!`H`````````@`````````0@,``!(`#`#@
M3`````````(`````````G0,``!``%0"(H@``````````````````'P0``!(`
M#`"(3````````%@`````````\P,``!(`#`#\'P```````"X`````````K0,`
M`!``%```H```````````````````J`0``!(`#`#(20```````%0`````````
M[P,``"``%```H```````````````````?@,``!``%@"PL@``````````````
M````8P,``!(`#``\+0```````!@`````````"00``!(`#`"8)@```````+H`
M````````700``!(`#`#T2@```````)0!````````4`0``!(`#`!,*0``````
M`)`#`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E
M;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&5X:70`<W1R;F-M
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]G=6%R9`!L:6)P97)L+G-O+C4N,S(`;&EB<'1H<F5A9"YS;RXP`&QI8F,N
M<V\N-@!L9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`7U]L:6)C7V-S=5]F
M:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`7U]"4U-?14Y$7U\`<&%R7V-L96%N=7``7V5D871A`%]?4T1!5$%?0D5'
M24Y?7P!?7T1!5$%?0D5'24Y?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`%]E;F0`7U]G;&]B86Q?<&]I;G1E<B0`<&%R7VEN:71?96YV
M`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(W```````"`````@`"`````@`"
M``(``@`"`````@`#```````#``(``P```````@````(``@````(``@`"````
M`@`#``(`!`````(``@````(``@`#`````@```````````````@```````@`"
M``(``@`"`````@`"```````"``(````"``(``@`#``(``@`"``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!`"8#```0````(````(>1E@8```0`QP0````````!``$`
M#`,``!`````@````AY&6!@```P#'!`````````$``0`<`P``$`````````"'
MD98&```"`,<$````````R)T````````#`````````"H@````````T)T`````
M```#`````````+X@````````V)T````````#`````````(0@`````````*``
M```````#``````````"@````````$*`````````#`````````/A,````````
M&*`````````#``````````A-````````(*`````````#`````````!!-````
M````**`````````#`````````!A-````````,*`````````#`````````"!-
M````````0*`````````#`````````+A0````````8*(````````#````````
M`%`>````````**(````````"`````P``````````````,*(````````"````
M!@``````````````.*(````````"````"0``````````````0*(````````"
M````$```````````````2*(````````"````%0``````````````4*(`````
M```"````(@``````````````6*(````````"````+@``````````````:*(`
M```````"````.0``````````````<*(````````"````.@``````````````
M>*(````````"````/@``````````````@*(````````"````0```````````
M````6*`````````%`````@``````````````8*`````````%````!```````
M````````:*`````````%````!0``````````````<*`````````%````!P``
M````````````>*`````````%````"```````````````@*`````````%````
M"@``````````````B*`````````%````"P``````````````D*`````````%
M````#```````````````F*`````````%````#0``````````````H*``````
M```%````#@``````````````J*`````````%````#P``````````````L*``
M```````%````$0``````````````N*`````````%````$@``````````````
MP*`````````%````$P``````````````R*`````````%````%```````````
M````T*`````````%````%@``````````````V*`````````%````%P``````
M````````X*`````````%````&```````````````Z*`````````%````&0``
M````````````\*`````````%````&@``````````````^*`````````%````
M&P```````````````*$````````%````'```````````````"*$````````%
M````'0``````````````$*$````````%````'@``````````````&*$`````
M```%````'P``````````````(*$````````%````(```````````````**$`
M```````%````(0``````````````,*$````````%````(P``````````````
M.*$````````%````)```````````````0*$````````%````)0``````````
M````2*$````````%````)@``````````````4*$````````%````*```````
M````````6*$````````%````*0``````````````8*$````````%````*@``
M````````````:*$````````%````*P``````````````<*$````````%````
M+```````````````>*$````````%````+0``````````````@*$````````%
M````+P``````````````B*$````````%````,```````````````D*$`````
M```%````,0``````````````F*$````````%````,@``````````````H*$`
M```````%````,P``````````````J*$````````%````-```````````````
ML*$````````%````-0``````````````N*$````````%````-@``````````
M````P*$````````%````-P``````````````R*$````````%````.```````
M````````T*$````````%````.P``````````````V*$````````%````/```
M````````````X*$````````%````/0``````````````Z*$````````%````
M00``````````````\*$````````%````0@``````````````^*$````````%
M````0P```````````````*(````````%````1```````````````"*(`````
M```%````10``````````````$*(````````%````1@``````````````&*(`
M```````%````1P``````````````EX,``#,#PT$#OH-:$P-#_9."@UH34Q,`
M@[*"`&<`#@`7C@```SZ.66<##@`3````%XX```,^#EEG`PX`$P```!>.```#
M/HY89P,.`!,````7C@```SX.6&<##@`3````%XX```,^CE=G`PX`$P```!>.
M```#/@Y79P,.`!,````7C@```SZ.5F<##@`3````%XX```,^#E9G`PX`$P``
M`!>.```#/HY59P,.`!,````7C@```SX.56<##@`3````%XX```,^CE1G`PX`
M$P```!>.```#/@Y49P,.`!,````7C@```SZ.4V<##@`3````%XX```,^#E-G
M`PX`$P```!>.```#/HY29P,.`!,````7C@```SX.4F<##@`3````%XX```,^
MCE%G`PX`$P```!>.```#/@Y19P,.`!,````7C@```SZ.4&<##@`3````%XX`
M``,^#E!G`PX`$P```!>.```#/HY/9P,.`!,````7C@```SX.3V<##@`3````
M%XX```,^CDYG`PX`$P```!>.```#/@Y.9P,.`!,````7C@```SZ.36<##@`3
M````%XX```,^#DUG`PX`$P```!>.```#/HY,9P,.`!,````7C@```SX.3&<#
M#@`3````%XX```,^CDMG`PX`$P```!>.```#/@Y+9P,.`!,````7C@```SZ.
M2F<##@`3````%XX```,^#DIG`PX`$P```!>.```#/HY)9P,.`!,````7C@``
M`SX.26<##@`3````%XX```,^CDAG`PX`$P```!>.```#/@Y(9P,.`!,````7
MC@```SZ.1V<##@`3````%XX```,^#D=G`PX`$P```!>.```#/HY&9P,.`!,`
M```7C@```SX.1F<##@`3````%XX```,^CD5G`PX`$P```!>.```#/@Y%9P,.
M`!,````7C@```SZ.1&<##@`3````%XX```,^#D1G`PX`$P```!>.```#/HY#
M9P,.`!,````7C@```SX.0V<##@`3````%XX```,^CD)G`PX`$P```!>.```#
M/@Y"9P,.`!,````7C@```SZ.06<##@`3````%XX```,^#D%G`PX`$P```!>.
M```#/HY`9P,.`!,````7C@```SX.0&<##@`3````%XX```,^CC]G`PX`$P``
M`!>.```#/@X_9P,.`!,````7C@```SZ./F<##@`3````%XX```,^#CYG`PX`
M$P```!>.```#/HX]9P,.`!,````=<:;DEX0``(.TQ#^<8"J'+N@RY`P(,`!H
M"#[TANPZSJ+HRN!._._PO^(7A@```S;F/;*%%X4```,U13[O('!EEX<``(.W
MASN#QP<`8XT'#A>$```3!`0_%XD```,YB3D#)0D`[_#?RP-'I4NJAP,E"0`3
M9R<`(XWG2N_P?\J#1Z5+<D:3YQ<`&P=&`",-]4H3%3<`&PDV`._PG]3"9?)'
M".288:J&&.$7-P``$P<'&QCE%X<```,WYQ,8Z1<W```3!T<:&.T%1V-:]PR;
MB#<`1HBA!1%'B&&3%S<`MI<%)XCCH07CF>C^FP<(``ALC@>VETJ&`4>7!0``
MDX7E:R.P!P#O\/_>*HDUQ0ALDPE!`N_P'\3.A1<U```3!:7J[P`@%3'-"&SO
M\+^^[_!_V2)WG&!C&O<&YF!&9*9DXGE*A09I)6&"@._PO\47A```$P1D+PCL
M,<7O\+^X%XD```,Y:2D#)0D`[_"_NX5G/I6C!`6F_;4(;._PO^`JB7FW"&@!
MQ>\0H&EYO\Z%%S4``!,%9=SO`.`-".A1U>6WD4>YMP5%[_#_VN_PO[T``.\`
MX`*JAQ>%```#->4E@F4P`!-Q`?^7-@``DX9FQQ<W```3!V?,"HCO\-^N`I"7
MD0``DX'AI8*````7A0``$P4E`9>'``"3AZ<`8XBG`)>'``"#M^<=D<."AX*`
M%X4``!,%!?^7A0``DX6%_HF-D]<U0/V1OI6%A9G%EX<``(.WIR"1PX*'@H!!
M$2+@%X0``!,$!""#1P0`!N2%XY>'``"#MP<>D<<7A0```S7E]8*7[_"_^(5'
M(P#T`*)@`F1!`8*`:;\Y<0;\(O@F]$KP3NQ2Z%;D6N!)P9>'``"#MT<6`[L'
M`&,*"P:#1P4`JHDNBBJ)$P?0`[W#8X;G`(-'&0`%"?W[.PDY00,T"P`=P-J$
MDPK0`R*%2H;.A>_PO\2S!R0!">6#QP<`8X!7`X!DH01U\.)P(H5"=*)T`GGB
M:4)JHFH":R%A@H"SA&1!C80%"2,@F@!*E/&_`43AOP%);;<5<<KA%XD```,Y
M"0^#-PD`ANVBZ:;E3OU2^5;U6O%>[6+I/N4)Q8-'!0`JA)7C*F>#-PD`8QWW
M#.Y@3F2N9`YIZGE*>JIZ"GOJ:TIL+6&"@._P7ZZJA&'=%SH``!,*2K>3"8$`
M/6N1:B:%[_"_FR7-@T8U`9,+-0&;AB;]@>:#QAL`_=(#1S4!&P<G_27'(H7O
M\%^E*HQ>A>_PWZ0[!:P`"27O\#^.WH<BA]*&?5:%1:J+[_`_BTZ&WH4!1>_P
MG[?]5V,(]0#B1[/W9P&!)V.,5P->A>_P'ZA>A>_PO\`FA>_P7Y11]2:%[_#?
MG"*%[_!_C36_`\<;`!L')_U)^P/'*P`]TVFW7H7O\)_O\;?O\'^6<7$F[9>$
M``"#M.3]G&`B\:J%*H0P``%%!O4^Y>_P?XL-X>)'O6819_6/8X7G`"EG8YKG
M`(E%(H7O\+^$$S45`!&@`44J9YQ@8Q?W`*IP"G3J9$UA@H#O\-^001$BX`;D
M*H3O\!^7$P;U_R*6$P?P`F-FQ`"MH'T68P7$!H-'!@#CB^?^$P?P`F-[Q`1]
M%F,*Q`2#1P8`XYOG_A,'\`(IH(-'!@!CE><`?1;C:\3^`8X3!R8`A6<!16/O
MYP"%9@4&HH47A0``$P4%^._PGZ,7A0``$P5%]Z)@`F1!`8*`XQ[$^@-'!`"3
M!_`"%S4``!,%A9UC!O<`%S4``!,%19T"9*)@00%O\._U77%6[/URA6JBX";\
M2OA.](;D4O`7B0```SEI[!:1_7>3A@H!`S<)`.$7BI8%9*Z)LX7V`).'B@"*
MEZJ$$P;T_Q<U```3!:68F./O\!^"FP<%`&-9\`03APH!"I<S!(=`&XKW_U*4
M`T>$_SWK8PP*`H5G?73!!V$4BI<^E%*&DP7P`B*%[_!_AA'-EX<``(.W!^2(
M0^_P;_;2AB*&IH7O\-^:(:B7AP``@[=GXHA#[_#/]$Z&IH7O\$_YA6>A!XJ7
MF&.#-PD`8Q_W`(5B%I&F8`9DXG1">:)Y`GKB:F%A@H`^BGFW[_!O]QUQHNBF
MY,K@4OB&[$[\5O1:\%[L8NB#QP4`%XD```,YB=T#-PD`DX<W_).W%P`SA/4`
MJH0BA3KD[_"O^BJ*3``FA>_P'\)YS:J)[_"/^6-Z10N229>*``"#NFK8$YLY
M``/'!`"FAY,&T`-C!P<28P;7``/'%P"%!WW[A9^#N0H`$P4J`#Z5VIGO\*_?
M(["I`"')DD8#MPH`@\<$`(X&-I<48Q.%%``3!M`#(X#V`('KA:B#1P4`!06C
M`/<`M<,VAX4&XYC'_I,&T`.3!Q<`(P#7``-'!`"%!P4$HX_G_G7[(F>#-PD`
M8Q[W"N9@1F2F9`9IXGE">J)Z`GOB:T)L)6&"@(-'!`"%"04$HX_Y_NG;@T<$
M`(4)!02CC_G^_?/)MS:'5;>7B@``@[IJRP.\"@"#-PP`I<?BAX%)F&?.AJ$'
MA2EE_XTFDY4V`)>'``"3AX?.F$,%ZP5'+H68P^_P;]*JBSW=$YLY`%J&XH7O
M\&_C([!Z`9N'&0".![Z;([`+`$["^;UBA>_PWX$CL*H`JHLAV1.;.0#YOX%'
MS;7!18%);;?O\`_=01$BX!>$```#-(3#"$`&Y._PS]4(0._P;]679@``DX:F
M81>&```#-J;`ER4``).%)7+O\*_L"$#O\$_3`F2B8!<W```3!\>E@4>ZAA<6
M```3!N;DER4``).%A7%!`6_P[^Y!$0;DEX<``(.W9[V(0^_PS\^B8)=F``"3
MAN9;%X8```,VYKJ7)0``DX5E;$$!;_#/YEUQ3O27B0``@[E)NU+P^7*#MPD`
M"6J&Y*+@)OQ*^!,'B@$6D0J7'./O\`_G>723!PH"BI<A%#Z4!68JAY<G``"3
MAT=KER8``).&1FL%!H5%(H7O\&^]_723!PH"BI?!%+Z4(H4%9J:%[_`/SAL$
M!0`!26-/!``;!10`[_#OO"J)`<DBAJ:%2I3O\`_0(P`$`(EGX0>*EYAC@[<)
M`&,=]P")8A:1IF!*A09DXG1">:)Y`GIA88*`[_`OR)FW47$%9OURHO&F[<KI
MTN%B\8;USN56_5KY7O5F[9,'!@D6D1>,```#/*RM?7H#-PP`DP9*]XJ7+H2S
MA=<`DP>&""J)BI<7)0``$P6%8)CC[_#_D:J$DP7P`DJ%[_`OP"G!%R4``!,%
MQ5_*A>_P'\I*A85GDX>'"(J7F&.#-PP`8Q'W%(5B%I&N<`YT[F1.::YI#FKJ
M>DI[JGL*?.IL;6&"@$J%[_"OQ*J*ER4``).%15PBA>_PK]V!*BJ$7=&%9Q.'
M!PF3"8K_"I>ZF1.'!PF#1P0`"I<%:Q,*BO>7+```DXPL4#J:LPMG0=G/D<2B
MA2:%[_#/W27-(H7O\$^_FP?U_[,&]``#Q@8`$P?P`@$E8Q[F`!,&\`(^A?TW
M(X`&`+,&]``#QP8`XPC'_IN'&@`]G>-89?,%9H5%2HB7)P``DX>G2B*'ER8`
M`).&!E-.A>_P[Z%2ALZ%`47O\$_.`>F#IXOXO68A9_6/8XSG`I<E``"3A050
M`47O\&_1*H3C`@7N@T<$`+WSD<2#QP0`FX<G_8''9H0%15&_@\<4`.';U;^%
M14Z%[_"/GW'QSH47)0``$P4%2^_P?[5.A>_P+YQ-O>_PSZL#1P4`JH<9RY,&
M\`*%!V,3UP`^A0/'!P!U^X*`@H`)Q8-'!0"1PVFR%R4``!,%!3]O\(^867&7
M9P``DX>G+J;LEX0``(.TA(^,:Y!OE'.8=XA@@]<'`Z+PRNC.Y(;T*OPNZ#+L
M-O`Z]",8\0)@`!<I```3":E$EXD``(.YJ8JBA4J%[_!O\A7!,D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P3_!E\1<I```3">E!EXD``(.YZ8:BA4J%
M[_"O[A7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PC^QE\1<I```3
M":D^EXD``(.Y*8.BA4J%[_#OZA7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_PS^AE\1<I```3">D[EWD``(.Y:7^BA4J%[_`OYQ7!,D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P#^5E\1<I```3":DXEWD``(.YJ7NBA4J%
M[_!OXQ7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P3^%E\1<I```3
M">DUEWD``(.YZ7>BA4J%[_"OWQ7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_PC]UE\1<I```3"2DKEWD``(.Y*72BA4J%[_#OVQ7!,D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PS]EE\1<I```3"6DOEWD``(.Y:7"BA4J%
M[_`OV!7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P#]9E\1<I```3
M":DLEWD``(.YJ6RBA4J%[_!OU!7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P3])E\1<I```3">DIEWD``(.YZ6BBA4J%[_"OT!7!,D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PC\YE\1<I```3"2D=EWD``(.Y*66BA4J%
M[_#OS!7!,D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PS\IE\:*%%R4`
M`!,%12/O\,_)JH49Q1<E```3!44@[_"_@J*%%R4``!,%Y2+O\._'JH49Q1<E
M```3!>4*[_#?@**%%R4``!,%A2+O\`_&JH4%S1<E```3!843[_#O_I<E``"3
MA44D%R4``!,%11CO\*_]8G><8&,6]P2F<`9TYF1&::9I96&"@**%%R4``!,%
M!1_O\(_!JH4!R1<E```3!047[_!O^F6_*4:7)0``DX6%'A,%$0+O\$^)5?&3
M!;$"Z;_OX)_O>7$B\!=T```#-`17'&`F[)=T``"3A,0QB$`^Y`;T_5=C"_4`
M(F<<8&,:]P*B<`)TXF1%88*`3``7)0``$P7%$._P3[JJAP%%@<N#QP<`B<<3
MA0?],S6@`(C`Z;?OX)_I01$&Y._@'_0!)>_PKXH1P0AAHF!!`8*`.7%*\!=Y
M```#.8E/@S<)`";T3`"JA!<E```3!645!OPB^$[L/N3O\&^T#<6#1P4`*H2-
MPZ:%[^!__QW-(F>#-PD`8QOW!N)P0G2B=`)YXFDA88*`(F>#-PD`IH5C'O<$
M0G3B<*)T`GGB:1<E```3!240(6%O\&_I)H7OX#_GJHDBA>_@O^9.E0D%[^`_
MT"*(ER<``).'Q_TFAX5%ER8``).&AOU]5BJ$[^!?S")G@S<)`**%XP;W^N_@
M7]PE<=+Z%WH```,ZRD,BZTKC`SX*`!=Y```3"4D>(63A<B;GSOX&[];VVO+>
M[N+J`S<)`Q:1DP0$%1,$A!3A=XJ4"I23A<?L`S.)`*:7@S@)`0,XB0$#-@D"
M@S:)`B,PQ`$7+@``$PX.!R.XQ^TCM.?R%RX``!,.#NL7)P``$P<'!JJ)II47
M)0``$P7%\".\Q^TCL`?N([CG[B.\!^XCL&?P([07\2.X!_$CO,?P([#7\N_P
M#Z`1Q8-'!0`JA&.5!SKOX!_;`27OX+_Q8P<%,`!A8P0$,"*%[^"_U08%!07O
MX#^_`T<$`*J*#</6A!<K```3"\O_)H7:AGU6A44%!._@/[L#1P0`B01U]R%G
M87N3!P<5DP0+\(J7OI23!P<5$PO+[(J7%R4``!,%1=P^FRF@B&2A!&,&!0[:
MA>_P;Y<JA&79@T<%`.W7[_!OL771(H7OX!^W*H1IQ2*%[^!_S:J$5H7OX/_,
MJ9R;A$1`)H7OX#^VUHB7)P``DX='VQ<H```3"$CW(H>7)@``DX8F]WU6A46J
MBN_@W[&3!0`<5H7OX#_3_5=C&/4`[^"?O1Q!14=CFN<HH6=A>Y.'!Q6*EQ,&
M"_,^EM:%`47OX)^V*H19S9=W``"#MP<I@[8)`(AC5H<7)@``$P:&]H5%[^!_
ML(%$H6>3AX<4BI>88X,W"@!C%O=(H6(6D?I@)H5:9+ID&FGV>59ZMGH6>_9K
M5FP=88*`H6>3AP<587N*ESZ;`S0+[8%$.:"3ES0`VI<#M`?M#<2#1P0`E<,B
MA>_P;Z&%)'W1(H7OX/^F*H3C$`7PDY<T`-J7`[0'[6G\`43]M:%GDX<'%8J7
MLXMG`8.G"_2]9A%G]8_CE^?T`ZR+]._@?[Z;!P4`XQ_\\H.G"_03!P`<D_?W
M'^.7Y_(FA>_@GZ*A9Y.'!Q63!<OLBI>JA+Z5%R4``!,%1>[OX-_^8PH%'`.[
M"0#OX!^?JH5:A>_PS^:JBV,/!1I>A>_@W[0;"P4`C4=CV&<#$P7+_Y<E``"3
MA27K7I7OX!_1">V11V,%^RZ;![O_WI<#QP<`DP?P`F,,]RR#)PD`?5=CB^<H
M8X$'&)<E``"3A<77%R4``!,%Q<WO\"^Q[^`?OBJ(ER@``).(J/27)P``DX>G
MO5:'ER8``).&!N=]5H5%)H7OX+^4?5G%21<L```3#"SRERL``).+*[L7*P``
M$PNKY26@[^"?GQQ!8Y<W`^_@_[@%)"J(8N"BB-Z'5H?:AGU6A44FA>_@?Y"3
M!0`<)H7OX-^QXP@E_5:%[^`_QZ:%%R4``!,%Q;SO\"^H)H7O\#^W*;TA9^%Z
MDP<'%1.+RNR*ESZ;DP<'%8J7@407)0``$P4%S;Z:.:"3ES0`UI<#M8?N!<7:
MA>_@?^J%)'75@T<%`/W3[^"?BBJ$XQL%RI.7-`#6EP.UA^YQ_35%[^`?BJJ*
M%R0``!,$),D3!S`%9;$7=P```S?'`0AC@[8)`%:'%R8``!,&1LN%1>_@/XF!
M1'&S[_#_K:%GDX>'%(J7F&.#-PH`8QGW(*%B%I'Z8+ID&FGV>59ZMGH6>_9K
M5FPBA5ID'6%OX)^"@[L)`(FUEW<``".K!]2!15Z%[^`_M2J+XPP%Y@E&N57O
MX%^(H6EA=).'"16*EQ,)A/\^F1E&RH5:A>_@OY:3APD5BI>BEP/'A_\9YP/'
ME_^3!C`$8P?7$@%&@45:A>_@?X3O$*!KH6=A=).'!Q43"83_BI>JB3Z9*:#*
MA4Z%[Q`@;R%FRH5:A>_@WY$;!@4`XT7`_EJ%[^#_ER%KDP<+%8J7$PD$^SZ9
MSH5*A>\0P'F3!PL5$P2$_(J7/I03"X0"ERD``).)R;@#1PD`(H7.AGU6A44)
M!._@[_,%">,6B_ZA9A.'!A4*E^%W,P/W`!.(A_PZF)<H``"3B`C0ER<``).'
M!YE6AY<F``"3AF;!?5:%12:%(P@#_N_@S^\1M:%GX763AP<5DX7%[(J7OI47
M)0``$P5EI._@_\WC!@7L@T<%`.."!^P3!P`#XX[GZH5'(R#Y`#6[@[F)`..$
M"=).A>_@7X.-1^/^I]!Q%9<E``"3A86Z3I7OX/^?XQ0%T,Z+";,#QJ?_DP80
M!.,7UNR#QK?_XY/F[(/&Q_\3!X`$XYWFZ@/'U_^3!U`$XQ?WZ@E&DP5@_%J%
M[^#O[LJ%$P:0`EJ%[^`O_I<H``"3B.C"2HB7)P``DX?'BU:'ER8``).&)K1]
M5H5%)H7OX,_B%;OOX&_S77&&Y*+@)OQ*^%+P3O16[!=T```#-"39%WD```,Y
MJ=F#-PD`"$`3"D$`/N3OX&_JJH0(0._@[^D#QX0+JH?2A1<E```3!262HXSG
M"N_@?[T9Q0-'!0"3!Q`#8P;W$N_P#\4(0._@[^:-1@5&ER4``).%9:_OX._U
MJH0%Q0A`[^!/Y9QH%R8``!,&9JZ,8^_@3^F<:)QCW$>;UV<!A8MCDP<0"$"7
M>0``DXGIU._@;^*-1@5&ER4``).%Y:OOX&_QJH0=P=*%%R4``!,%Q83OX%^U
MJHH(0&.-"@KOX(_?G&A6AHQC[^#OXPA`[^"/WJJ$"$#OX`_>!4:7)0``DX4E
MJ._@+_.JA1<F```3!L:H)H7OX"_A"$#OX,_;HPP%"M*%%Q4``!,%)7[OX+^O
M([BI`"J$!<V3!0`<(H7OX(_PQ4=C!_4`FP<5``5'8V7W!B)G@S<)`&,;]P:F
M8`9DXG1">:)Y`GKB:F%A@H`#M8D`[_!?@".XJ0`JA%7]%R4``!,%!:+OX`_M
M@T<5`..,!^S!O>_@+]0#MXD`G&@,8XAC[^"_TYFW"$#OX,_2G&B,8^_@3^W%
MO8.WB0"JAB*&C&,7)0``$P5%H._@S^COX(_6.7%*\!=Y```#.0F^@S<)`"+X
M!OPF]$[L/N0JA"G-@T<%`+'+[^"?PX-'!0"JA)'+$P?P`@4%8Y/G`*J$@T<%
M`/7[EWD``).)J96#IPD`?5=CBN<"B<<!Q(-'!`"AZR)G@S<)`&,0]PCB<$)T
MHG0">>)I(6&"@!<5```3!>5D[^!OOEVW3``7%0``$P7E<N_@?YPAQ8-'!0"I
MPQ,'``-CCN<"A4<CH/D`1?A5OQ%&EQ4``).%97XFA>_@S^--\2)G@S<)`&,0
M]P(BA4)TXG"B=`)YXFDA86_@OZ&7=P``(Z$'C+6_[^`/R!,!`=,C-!$L(S"!
M+",\D2HC."$K(S0Q*R,P02LC/%$IEW@``(.XR*V#MP@`.`#]7T%O(S3Q*!,#
MA0.3`X4'.HB3WP\"MP+_`!,/#_`#-@,`00@A`Y-5!@*3%H8!$Q2&`)-7A@*3
M7H8`DU2&`Q.>A0&S]O8!,W14`+/WYP'!CK/^[@'%CS-^_@&B!;/FU@$;5H8!
ML^?'`;/U50#1CLV/(SC8_B,\^/[CDV/Z?583`P<@`9(\=P,X!P0,:Q1CL\<'
M`:V/M8^3EA<`_8/5C_&/7.,A!^,09_Z#/@4`HF(,:0,XA0$#,X4``SX%`C>'
M@EH3!Y>9D]>^`1.?7@`S;_\`NI*SQ@4!\I*3'^,!,W_/`)-7(P"SY_\`%I^S
M]F8`PF*S_\<`L\8&`3:?L\;U`3-_SP"S]M8!NI+"DI,37P"35+\!K8Z6EK/B
MDP`3F>X!$]0N`):6XF(S9(D`H8^S]^<!NI+QCJZ2L\?W`9.45@`3V;8!DQ/O
M`9:7$U\O`()RL^/C`3/O)`'ZES-/=`"ZDG&,,W_?`/&/EI\S3X\`DY17`!/9
MMP&3DN8!?I^)@J)_L^+2`+/F)`$VG[/&4P`S?\\`L_/#`/V.NI^BGY,47P`3
M6;\!L\9V`!.4YP&)@UV,_I:SYR0!OI:S_\8`PG:SQX(`L_?G`;/RP@"ZEIZ6
MDY1?`!/9OP&SQU<`MI>SYB0!MI>3$^\!$U\O`+/CXP$S_\<`XG>S1G0`L_;V
M`7&,NI>6EY,47P`36;\!H8Z^EK/G)`&^EI.2[P&3WR\`L^+R`;/_Q@"&9K/'
M4P"S]^<!L_/#`+J6HI:3E%\`$]F_`;/'=P"VE[/F)`&VEQ,4[P$37R\`,V3D
M`3/_QP"F9[/&@@"S]O8!L_+"`+J7GI>3%%\`$UF_`;/&5@"^EK/G)`&^EI.3
M[P&3WR\`L^/S`;/_Q@#&9K-'=`"S]^<!<8RZEI:6DY1?`!/9OP&AC[:7L^8D
M`;:7DQ+O`1-?+P"SXN(!,__'`.9GL\93`+/V]@&S\\,`NI>BEY,47P`36;\!
ML\9V`+Z6L^<D`;Z6$Y3O`9/?+P`S9/0!L__&`(9VL\>"`+/WYP&S\L(`NI:>
MEI.47P`3V;\!L\=7`+:7L^8D`;:7DQ/O`1-?+P"SX^,!,__'`*9WLT9T`+/V
M]@%QC+J7EI>3%%\`$UF_`:&.OI:SYR0!OI:3DN\!D]\O`+/B\@&S_\8`QG:S
MQU,`L_?G`;/SPP"ZEJ*6DY1?`!/9OP&SQW<`MI>SYB0!MI<3%.\!$U\O`#-D
MY`$S_\<`YG>SQH(`L_;V`;/RP@"ZEYZ7DQ1?`!-9OP&SQE8`OI:SYR0!OI:3
MD^\!D]\O`+/C\P&S_\8`BF:S1W0`L_?G`7&,NI:6EI.47P`3V;\!H8^VE[/F
M)`&VEY,2[P$37R\`L^+B`3/_QP"J9[/&4P"S]O8!L_/#`+J7/I2SQG8`DU2_
M`1.9[P&3%U\`HI:3WR\`2F2S;_D!Q8^^EK/'\@'QCK/RP@`ZE+/WYP&BDY/4
MM@&SQU<`$Y16`$6,GI?J9),3[P$37R\`L^/C`:*7\8\SSW\`NI2S_\\`$]FW
M`3-_WP`3E%<`II(S3_\!,V0D`7&,"GD6GY.2Y@&)@B*?L^+2`+-TSP"SQE,`
M_8ZS\\,`.ID3E%0`D]FT`3/'=@"S!OD!LV\T`1.4YP&)@UV,L\>"`#:7L__/
M`+/'YP$J?[J?-_?9;A,'%[JS^<\`.I\3V;D!DY99`/J3\8^SYB8!GI?QCKZ6
MDY/D`<IWB8"SXY,`,_G&`#-/=`"S\L(`DU2Y`;J7LT__`1,?60"S_\\`EI<S
M;Y\`_I<S?\\`/I^3DND!ZG>3V2D`L^(R`;-TSP"SSU,`<8R3V;0!NI>SS]\`
MDY94`+/_SP"BE[/F-@'^E_&.OI:3'^D!CF<362D`L^\O`3/TQ@`SR?(!L_G#
M`+J7LT/I`1-9M`$3'U0`L_/#`,Z7,V\O`9Z7,W_/`#Z?DY/D`:YGB8"SXY,`
M,\E_`+-TSP"S^<(`NI>S0MD`$]FT`9.65`"S\L(`SI>SYB8!EI?QCKZ6DQ+D
M`<YG"8"SXH(`,\E3`#/TQ@"S^<\`NI>S3^D!$UFT`1,?5`"S_\\`SI<S;R\!
M_I<S?\\`/I^3G^0![F>)@+/OGP`SR?(!LW3/`+/YPP"ZE[-#V0`3V;0!DY94
M`+/SPP#.E[/F)@&>E_&.OI:3$^0!CG<)@+/C@P`SR7\`,_3&`+/YP@"ZE[-"
MZ0$36;0!$Q]4`+/RP@#.ES-O+P&6ES-_SP`^GY.2Y`&N=XF`L^*2`#/)4P"S
M=,\`L_G/`+J7LT_9`!/9M`&3EE0`L__/`,Z7L^8F`?Z7\8Z^EI,?Y`'.=PF`
ML^^/`#/)\@$S],8`L_G#`+J7LT/I`1-9M`$3'U0`L_/#`,Z7,V\O`9Z7,W_/
M`#Z?DY/D`>YWB8"SXY,`,\E_`+-TSP"S^<(`NI>S0MD`$]FT`9.65`"S\L(`
MSI>SYB8!EI?QCKZ6DQ+D`9)G"8"SXH(`,\E3`#/TQ@"S^<\`NI>S3^D!$UFT
M`1,?5`"S_\\`SI<S;R\!_I<S?\\`/I^3G^0!LF>)@+/OGP`SR?(!LW3/`+/Y
MPP"ZE[-#V0`3V;0!DY94`+/SPP#.E[/F)@&>E_&.OI:3$^0!TF<)@+/C@P`S
MR7\`,_3&`+/YP@"ZE[-"Z0$36;0!$Q]4`+/RP@#.ES-O+P&6ES-_SP`^GY.2
MY`'R9XF`L^*2`#/)4P"S=,\`L_G/`+J7LT_9`!/9M`&3EE0`L__/`,Z7L^8F
M`?Z7\8Z^EI,?Y`&2=PF`L^^/`#/YQ@`SQ/(!L_G#`+J7LT/D`1-4N0$3'UD`
ML_/#`,Z7,V^/`)Z7,W_/`#Z?$Y3D`;)WB8!%C+/#CP"S=,\`L_G"`+J7L\+3
M`)/3M`&3EE0`L_+"`,Z7L^9V`):7\8Z^EI,2Z0'2=Q-9*0"SXB(!LT-4`#/Y
MQ@"S^<\`NI<SS^,!DQ]9`)-3N0$S?\\`SI>S[W\`^I>S_\\`OI^3D^0!\G>)
M@+/CDP`SSW(`L_3/`'&,NI>S1M\`,__&`)/9M`&BEQ.45`#ZES-O-`'ZEY,6
MZ0$6;Q-9*0"SYB8!,\G3`#/TQP"S\L(`LT?Y`3J?\8\35[0!%I\3&50`DY_D
M`8F`L^^?`#-IZ0`^G[/TQ@!*G[/F]@&S\L\`,W_/`#?WQB,S]H8`MF;]5PH'
M@9,3!\?-,_E4`+J6L_/S`+:3DUF_`3-F)@$3&5\`$QKD`9-6)``>EC-D.0$B
MEC-T]@!69K-FV@"S\_8`L^_?`#/Y<@`ZEK/_[P&RE)-9M`&S[R\!$QE4`*:?
MLV0Y`1,6[P&FGQ-?+P#V9#-FY@$S?_8`T8ZS__\`,_GC`>&.NI26E)/9OP&S
MYB8!$YE?`*:6LV0Y`1,:Y`&34B0`II:6=+-B6@`S]/(`,V96`/V.,WF/`+J4
M,W;V`::3,V8F`9.45@`3V;8!L^0D`1Z6DYGO`2:6D]\O`+9TL^_Y`;/S_P"S
MXO(!?8XS>70`L_+2`+J4L^(B`?J4$QE6`)-9M@$3G^8!B8(S;]\`LX:2`+-B
M.0&6EM9RLW3_`+/O[P']CC/YDP"ZDK/_SP"S[R\!%I03F58`D]FV`9,2Y@$)
M@K/BP@`SAH\`LV\Y`7Z6]G\S]/(`,V]?`'V.,_F$`+J?,W_?`#-O+P'^DQ,9
M5@"36;8!DY_F`8F"L^_?`+,&?P`S;SD!^I8:;[/S_P"SXO(!_8XS>70`.I^S
M\L(`L^(B`?J4$YE6`)/9M@$3'^8!"8(S;\\`,X:2`+-B.0$6EKIBLW3_`+/O
M[P%]CC/YDP"ZDK/_WP"S[R\!%I03&58`DUFV`9.2Y@&)@K/BT@"SAH\`LV\Y
M`?Z6VF\S]/(`,V]?`/V.,_F$`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"
ML^_/`#,&?P`S;SD!>I9Z;[/S_P"SXO(!?8XS>70`.I^S\M(`L^(B`?J4$QE6
M`)-9M@$3G^8!B8(S;]\`LX:2`+-B.0&6EIIRLW3_`+/O[P']CC/YDP"ZDK/_
MSP"S[R\!%I03F58`D]FV`9,2Y@$)@K/BP@`SAH\`LV\Y`7Z6NG\S]/(`,V]?
M`'V.,_F$`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?`+,&?P`S;SD!
M^I9:?[/S_P"SXO(!_8XS>70`.I^S\L(`L^(B`?J4$YE6`)/9M@$3'^8!"8(S
M;\\`,X:2`+-D.0$FEOITLW+_`+/O[P%]CC/Y4P"S_]\`NI2S[R\!HI03&58`
MDUFV`1.4Y@&)@E6,LX:?`+-D.0$>:;-_]``S;X\`II8S?\\`L_3R`3J9_8X>
MF3-OGP"3F58`$]JV`9-3)@"3%.8!2I\^:;/D=``SYDD!L_/T`#*?,V:4`'6.
M,W3_`#J9,_]_`!:9DQE4`!-:M`$S9N8!D](F`!.?Y@%*EK/F20$S;U\`-I:S
MYN0!LW3V`%YFLW+_`#/Y4P`ZEN&.LI^SYB8!$Y94`!/9M`'^EK-O)@'^EA,6
MY`'^;PF`08[]CC-T]@`S;\\`,_J"`+J?D]FV`3-_GP`3F58`_I,S;T\!,VDY
M`3-Y^0">>9/?)``>GY.3Y`&SX_,!2I^S=/\`L__S`#-F=@!UCK-Z]`&ZF1.9
M5``3VK0!SI(S9U8!,VE)`1:7$]8F`#-Y^0"3DN8!L^+"`#J9/G8WMY@R"@<3
M!V<=LWGY`+/&4P`ZEI/3N0&SQN8!$Y]9`#*4_8XS;W\`HI8S?_\`$Y3D`=YS
MB8!%C#:?LW3_`#/&@@"ZDS-&)@&3EE0`$]FT`9Z??8ZSYB8!_8Y^EC:6DY_I
M`?YVD]DI`+/O/P$S>?8`LT/T`;/Y\@"ZEK/"XP&34[D!$Q]9`+/R\@#.EC-O
M?P"6EC-__P`VGY.3Y`&#-@$@B8"SXY,`L\)_`+-T_P!]C)/9M`&ZEK/"P@`3
MEE0`L_+R`**6,V8V`9:6?8XVEI,2Z0&#-H$@$UDI`+/B(@$S=/8`,\E3`+/Y
M_P"ZEK-/Z0$36;0!$Q]4`+/__P#.EC-O+P'^EC-__P`VGY.?Y`&#-@$AB8"S
M[Y\`,\GR`;-T_P"S^?,`NI:S0\D`$]FT`1.65`"S\_,`SI8S9B8!GI9]CC:6
MDQ/D`8,V@2$)@+/C@P`SR7\`,W3V`+/Y\@"ZEK-"Z0$36;0!$Q]4`+/R\@#.
MEC-O+P&6EC-__P`VGY.2Y`&#-@$BB8"SXI(`,\E3`+-T_P"S^?\`NI:S3\D`
M$]FT`1.65`"S__\`SI8S9B8!_I9]CC:6DQ_D`8,V@2()@+/OCP`SR?(!,W3V
M`+/Y\P"ZEK-#Z0$36;0!$Q]4`+/S\P#.EC-O+P&>EC-__P`VGY.3Y`&#-@$C
MB8"SXY,`,\E_`+-T_P"S^?(`NI:S0LD`$]FT`1.65`"S\O(`SI8S9B8!EI9]
MCC:6DQ+D`8,V@2,)@+/B@@`SR5,`,W3V`+/Y_P"ZEK-/Z0$36;0!$Q]4`+/_
M_P#.EC-O+P'^EC-__P`VGY.?Y`&#-@$DB8"S[Y\`,\GR`;-T_P"S^?,`NI:S
M0\D`$]FT`1.65`"S\_,`SI8S9B8!GI9]CC:6DQ/D`8,V@20)@+/C@P`SR7\`
M,W3V`+/Y\@"ZEK-"Z0$36;0!$Q]4`+/R\@#.EC-O+P&6EC-__P`VGY.2Y`&#
M-@$EB8"SXI(`,\E3`+-T_P"S^?\`NI:S3\D`$]FT`1.65`"S__\`SI8S9B8!
M_I9]CC:6DQ_D`8,V@24)@+/OCP`SR?(!,W3V`+/Y\P"ZEK-#Z0$36;0!$Q]4
M`+/S\P#.EC-O+P&>EC-__P`VGY.3Y`&#-@$FB8"SXY,`,WG_`+/$?P"S^?(`
MNI:SPL0`DU2Y`1,660"S\O(`SI9%CI:6?8XVEI,4Y`&#-H$F"8#!C+/"DP`S
M=/8`L_G_`+J6,\_B`9,?5`"34K0!,W__`,Z6L^]?`/J6L___`+:?DQ+I`8,V
M`2<362D`L^(B`3//5``S^?\`L_/S`#-/SP"36;D!NI83%ED`,V8V`9Z6LW/_
M`!,?Y`$)@#-OCP`S=/8``S:!)YZ6-I2SQN(!LW/T`/V,.I:SQO8!_8XFEI/9
MLP&3E%,`-I:SYC0!-I:#-@$HDQ_I`1-9*0"S[R\!NI:S1/\!,W?V`+/R\@#V
MEC/&A`!]CI,>5P"6EI-2MP&REC/F7@"REOV.$Y;C`9/3(P`4X;-F=@`:E[:5
M,X8/`8,^@2AZG@.X"`"S=O<`?8XS]_4`LW?^`!3E&.D0[1SQ8Y,.`X,P@2P#
M-`$L@S2!*P,Y`2N#.8$J`SH!*H,Z@2D3`0$M@H#OT,^@01$3!0`(!N3OT`^1
MMW9=3(8&DX;FSS=WZ6$W)D5G%.D3!A8PMU8R$`8'$.&3AF9'%T8```,VAB<3
M!P<?$.44[1CQ(S0%`B,X!0(C+`4&HF!!`8*`.7$B^";T2O!6Y`;\3NQ2Z!AU
MDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7U@$VEYSTF/@RB2Z$DXJ$`S'MDP?P
M`V/:)PD;"0G\&UII`)L)&@":":*9HH43!@`$5H7OT(^:$P0$!":%[^`_S>,5
M-/\;&FH`.PE)04J&SH56A>_0CY@CK"0'XG!"=*)T`GGB:4)JHFHA88*`DP<`
M!#N'IT"RB6-(QP(;B@D`4H:BA5:5[]!OE;Q<$P<`!+N&-P&TW..3YOPFA3L)
M.4%2E._@_\:]M[J)R;^BB46W.7$B^";T2O!.[%K@!OQ2Z%;D@]>%`@/7!0,#
MNH4"&YD'`9L9!P$35CH`&UD)`9O9"0$3=O8#$XN%`QM9B0";V8D`FY>'`!L7
MAP`NA+/G)P&S!<L`,V<W`1,(`/B3!A8`@SH$`Q.9!P,C@`4!DQD'`Y,%@`.J
MA!-9"0.3V0D#!28S!=L`8]#5$),'``0[AL=`@47OT*^J(H7OX)^\$P:``X%%
M6H7OT(^IDU>*`1/7B@$36@H!D]H*`2*%HPA4!R,9-`<C"O0&HPI$!R,;)`<C
M".0&[^#_N!Q@(H7A@R.`]``<8,&#HX#T`!Q@H8,C@?0`'&"C@?0`'&3A@R."
M]``<9,&#HX+T`!QDH8,C@_0`'&2C@_0`'&CA@R.$]``<:,&#HX3T`!QHH8,C
MA?0`'&BCA?0`'&SA@R.&]``<;,&#HX;T`!QLH8,CA_0`'&RCA_0`''#A@R.(
M]``<<,&#HXCT`!QPH8,CB?0`''"CB?0`0G3B<*)T`GGB:4)JHFH":R%A;]#/
MG),'@`,[AL=`@47OT.^:&;\Y<2+X2O`75```$P0D%!=9```3"2D4,PF)0`;\
M)O1.[%+H5N0363E`8P\)`*J)+HJRBH%$'&!6AM*%3H6%!(*7(03C&9G^XG!"
M=*)T`GGB:4)JHFHA88*`@H"75@``@[;F,6_0;XP```$``@``````4$%27U1-
M4$1)4@```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````)7,O
M)7,````N`````````"\`````````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`
M````97AE```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!
M4E]04D]'3D%-10`````Z`````````"5S)7,E<P``4$523#5,24(`````````
M`%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'
M`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'````````
M``!005)?1TQ/0D%,7U1-4$1)4@````````!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@``````````4$%27T-,14%./0```````#$`````````
M3$1?3$E"4D%265]0051(`%5315(`````4UE35$5-```O=&UP`````%5315).
M04U%```````````E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M```````8`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`U,@```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90``````
M`"TM````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P
M;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@
M,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P
M*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O
M<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H
M;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA
M9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S
M:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P
M;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B
M=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F
M:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@
M(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z
M("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@
M<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@
M9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM
M>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@
M*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R
M968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B
M+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO
M)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^
M<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS
M<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI:
M:7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U
M=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@
M+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E
M=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@
M?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%
M04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B
M.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E
M7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R
M:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A
M<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("([
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``'!E<FQX<VDN8P``````
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````B:O-
M[P`````!&P,[%`````$```"$D___+``````````0``````````-Z4@`!?`$!
M&PT"`!`````8````4)/__RX`````!P$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````!`````````/P"`````````0`````````,`P````````$`````````
M'`,````````!`````````"8#````````(`````````#(G0```````"$`````
M````"``````````9`````````-"=````````&P`````````(`````````!H`
M````````V)T````````<``````````@`````````]?[_;P````"@`@``````
M``4`````````.`T````````&`````````)`#````````"@````````#2!```
M``````L`````````&``````````5`````````````````````P````````!(
MH`````````(`````````6`4````````4``````````<`````````%P``````
M``!(%0````````<`````````.!,````````(`````````&@'````````"0``
M```````8`````````!X`````````"`````````#[__]O``````$```@`````
M_O__;P````#8$@```````/___V\``````P````````#P__]O``````H2````
M````^?__;P`````+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````*`:````````H!H```````"@&@```````*`:````````H!H`````
M``"@&@```````*`:````````H!H```````"@&@```````*`:````````H!H`
M``````"@&@```````*`:````````H!H```````"@&@```````*`:````````
MH!H```````"@&@```````*`:````````H!H```````"@&@```````*`:````
M````H!H```````"@&@```````*`:````````H!H```````"@&@```````*`:
M````````H!H```````"@&@```````*`:````````H!H```````"@&@``````
M`*`:````````H!H```````"@&@```````*`:````````H!H```````"@&@``
M`````*`:````````H!H```````"@&@```````*`:````````H!H```````"@
M&@```````*`:````````H!H```````"@&@```````*`:````````H!H`````
M``"@&@```````*`:````````H!H```````"@&@```````*`:````````H!H`
M``````"@&@```````."=````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1T-#.B`H56)U;G1U(#$P+C(N
M,2TQ.'5B=6YT=3(I(#$P+C(N,2`R,#(Q,#$S,```+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YP<F5I;FET7V%R<F%Y`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YG;W0`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@`````````X`@```````#@"
M````````(0````````````````````$````````````````````3````!P``
M``(`````````7`(```````!<`@```````"0````````````````````$````
M````````````````)@````<````"`````````(`"````````@`(````````@
M````````````````````!````````````````````#0```#V__]O`@``````
M``"@`@```````*`"````````\``````````%``````````@`````````````
M```````^````"P````(`````````D`,```````"0`P```````*@)````````
M!@````(````(`````````!@`````````1@````,````"`````````#@-````
M````.`T```````#2!````````````````````0```````````````````$X`
M``#___]O`@`````````*$@````````H2````````S@`````````%````````
M``(``````````@````````!;````_O__;P(`````````V!(```````#8$@``
M`````&``````````!@````,````(````````````````````:@````0````"
M`````````#@3````````.!,````````0`@````````4`````````"```````
M```8`````````'0````$````0@````````!(%0```````$@5````````6`4`
M```````%````%0````@`````````&`````````!Y`````0````8`````````
MH!H```````"@&@```````+`#```````````````````0`````````!``````
M````?@````$````&`````````%`>````````4!X```````">+@``````````
M````````!````````````````````(0````!`````@````````#P3```````
M`/!,````````B#\```````````````````@```````````````````",````
M`0````(`````````>(P```````!XC````````!0````````````````````$
M````````````````````F@````$````"`````````)",````````D(P`````
M```L````````````````````"````````````````````*0````0`````P``
M``````#(G0```````,B-````````"`````````````````````$`````````
M"`````````"S````#@````,`````````T)T```````#0C0````````@`````
M```````````````(``````````@`````````OP````\````#`````````-B=
M````````V(T````````(````````````````````"``````````(````````
M`,L````&`````P````````#@G0```````."-````````(`(````````&````
M``````@`````````$`````````#4`````0````,``````````*``````````
MD````````$@````````````````````(````````````````````V@````$`
M```#`````````$B@````````2)````````!``@``````````````````"```
M```````(`````````-\````(`````P````````"(H@```````(B2````````
M*!````````````````````@```````````````````#D`````0```#``````
M``````````````"(D@```````"\````````````````````!``````````$`
M`````````0````,`````````````````````````MY(```````#M````````
9`````````````0``````````````````````
